@@ -38,7 +38,7 @@ static GstStaticPadTemplate gst_gdk_pixbuf_dec_sink_template =
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("image/png; "
         /* "image/jpeg; " disabled because we can't handle MJPEG */
-        "image/gif; "
+        /*"image/gif; " disabled because we can't handle animated gifs */
         "image/x-icon; "
         "application/x-navi-animation; "
         "image/x-cmu-raster; "
@@ -180,10 +180,10 @@ gst_gdk_pixbuf_dec_class_init (GstGdkPixbufDecClass * klass)
   gstelement_class->change_state =
       GST_DEBUG_FUNCPTR (gst_gdk_pixbuf_dec_change_state);
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&gst_gdk_pixbuf_dec_src_template));
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&gst_gdk_pixbuf_dec_sink_template));
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &gst_gdk_pixbuf_dec_src_template);
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &gst_gdk_pixbuf_dec_sink_template);
   gst_element_class_set_static_metadata (gstelement_class,
       "GdkPixbuf image decoder", "Codec/Decoder/Image",
       "Decodes images in a video stream using GdkPixbuf",
@@ -215,6 +215,7 @@ gst_gdk_pixbuf_dec_init (GstGdkPixbufDec * filter)
 
   filter->last_timestamp = GST_CLOCK_TIME_NONE;
   filter->pixbuf_loader = NULL;
+  filter->packetized = FALSE;
 }
 
 static gboolean
@@ -227,6 +228,8 @@ gst_gdk_pixbuf_dec_setup_pool (GstGdkPixbufDec * filter, GstVideoInfo * info)
   guint size, min, max;
 
   target = gst_pad_get_current_caps (filter->srcpad);
+  if (!target)
+    return FALSE;
 
   /* try to get a bufferpool now */
   /* find a pool for the negotiated caps now */
@@ -246,6 +249,8 @@ gst_gdk_pixbuf_dec_setup_pool (GstGdkPixbufDec * filter, GstVideoInfo * info)
     min = max = 0;
   }
 
+  gst_query_unref (query);
+
   if (pool == NULL) {
     /* we did not get a pool, make one ourselves then */
     pool = gst_buffer_pool_new ();
@@ -365,7 +370,8 @@ gst_gdk_pixbuf_dec_flush (GstGdkPixbufDec * filter)
   /* ERRORS */
 no_pixbuf:
   {
-    GST_ELEMENT_ERROR (filter, STREAM, DECODE, (NULL), ("error geting pixbuf"));
+    GST_ELEMENT_ERROR (filter, STREAM, DECODE, (NULL),
+        ("error getting pixbuf"));
     return GST_FLOW_ERROR;
   }
 channels_not_supported:
@@ -410,9 +416,9 @@ gst_gdk_pixbuf_dec_sink_event (GstPad * pad, GstObject * parent,
         /* as long as we don't have flow returns for event functions we need
          * to post an error here, or the application might never know that
          * things failed */
-        if (res != GST_FLOW_OK && res != GST_FLOW_FLUSHING) {
-          GST_ELEMENT_ERROR (pixbuf, STREAM, FAILED, (NULL),
-              ("Flow: %s", gst_flow_get_name (res)));
+        if (res != GST_FLOW_OK && res != GST_FLOW_FLUSHING
+            && res != GST_FLOW_EOS && res != GST_FLOW_NOT_LINKED) {
+          GST_ELEMENT_FLOW_ERROR (pixbuf, res);
           forward = FALSE;
           ret = FALSE;
         }
@@ -424,12 +430,32 @@ gst_gdk_pixbuf_dec_sink_event (GstPad * pad, GstObject * parent,
       pixbuf->pending_events = NULL;
       /* Fall through */
     case GST_EVENT_SEGMENT:
+    {
+      const GstSegment *segment;
+      GstSegment output_segment;
+      guint32 seqnum;
+
+      gst_event_parse_segment (event, &segment);
+      if (segment->format == GST_FORMAT_BYTES)
+        pixbuf->packetized = FALSE;
+      else
+        pixbuf->packetized = TRUE;
+
+      if (segment->format != GST_FORMAT_TIME) {
+        seqnum = gst_event_get_seqnum (event);
+        gst_event_unref (event);
+        gst_segment_init (&output_segment, GST_FORMAT_TIME);
+        event = gst_event_new_segment (&output_segment);
+        gst_event_set_seqnum (event, seqnum);
+      }
+
       if (pixbuf->pixbuf_loader != NULL) {
         gdk_pixbuf_loader_close (pixbuf->pixbuf_loader, NULL);
         g_object_unref (G_OBJECT (pixbuf->pixbuf_loader));
         pixbuf->pixbuf_loader = NULL;
       }
       break;
+    }
     default:
       break;
   }
@@ -479,9 +505,7 @@ gst_gdk_pixbuf_dec_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
           &error))
     goto error;
 
-  /* packetised mode? *//* FIXME: shouln't this be fps_d != 0, since 0/1
-   * might be packetised mode but variable framerate */
-  if (filter->in_fps_n != 0) {
+  if (filter->packetized == TRUE) {
     gdk_pixbuf_loader_close (filter->pixbuf_loader, NULL);
     ret = gst_gdk_pixbuf_dec_flush (filter);
     g_object_unref (filter->pixbuf_loader);
@@ -537,6 +561,11 @@ gst_gdk_pixbuf_dec_change_state (GstElement * element,
       }
       g_list_free_full (dec->pending_events, (GDestroyNotify) gst_event_unref);
       dec->pending_events = NULL;
+      if (dec->pixbuf_loader != NULL) {
+        gdk_pixbuf_loader_close (dec->pixbuf_loader, NULL);
+        g_object_unref (G_OBJECT (dec->pixbuf_loader));
+        dec->pixbuf_loader = NULL;
+      }
       break;
     default:
       break;
