@@ -42,34 +42,34 @@
 
 /**
  * SECTION:element-jackaudiosrc
+ * @title: jackaudiosrc
  * @see_also: #GstAudioBaseSrc, #GstAudioRingBuffer
  *
  * A Src that inputs data from Jack ports.
- * 
- * It will create N Jack ports named in_&lt;name&gt;_&lt;num&gt; where 
+ *
+ * It will create N Jack ports named in_&lt;name&gt;_&lt;num&gt; where
  * &lt;name&gt; is the element name and &lt;num&gt; is starting from 1.
  * Each port corresponds to a gstreamer channel.
- * 
+ *
  * The samplerate as exposed on the caps is always the same as the samplerate of
  * the jack server.
- * 
+ *
  * When the #GstJackAudioSrc:connect property is set to auto, this element
- * will try to connect each input port to a random physical jack output pin. 
- * 
+ * will try to connect each input port to a random physical jack output pin.
+ *
  * When the #GstJackAudioSrc:connect property is set to none, the element will
  * accept any number of output channels and will create (but not connect) an
  * input port for each channel.
- * 
+ *
  * The element will generate an error when the Jack server is shut down when it
  * was PAUSED or PLAYING. This element does not support dynamic rate and buffer
  * size changes at runtime.
- * 
- * <refsect2>
- * <title>Example launch line</title>
+ *
+ * ## Example launch line
  * |[
  * gst-launch-1.0 jackaudiosrc connect=0 ! jackaudiosink connect=0
  * ]| Get audio input into gstreamer from jack.
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -469,9 +469,15 @@ gst_jack_ring_buffer_acquire (GstAudioRingBuffer * buf,
     /* find all the physical output ports. A physical output port is a port
      * associated with a hardware device. Someone needs connect to a physical
      * port in order to capture something. */
-    ports =
-        jack_get_ports (client, NULL, NULL,
-        JackPortIsPhysical | JackPortIsOutput);
+
+    if (src->port_pattern == NULL) {
+      ports = jack_get_ports (client, NULL, NULL,
+          JackPortIsPhysical | JackPortIsOutput);
+    } else {
+      ports = jack_get_ports (client, src->port_pattern, NULL,
+          JackPortIsOutput);
+    }
+
     if (ports == NULL) {
       /* no ports? fine then we don't do anything except for posting a warning
        * message. */
@@ -496,7 +502,7 @@ gst_jack_ring_buffer_acquire (GstAudioRingBuffer * buf,
       if (res != 0 && res != EEXIST)
         goto cannot_connect;
     }
-    free (ports);
+    jack_free (ports);
   }
 done:
 
@@ -531,7 +537,7 @@ cannot_connect:
     GST_ELEMENT_ERROR (src, RESOURCE, SETTINGS, (NULL),
         ("Could not connect input ports to physical ports (%d:%s)",
             res, g_strerror (res)));
-    free (ports);
+    jack_free (ports);
     return FALSE;
   }
 }
@@ -680,7 +686,7 @@ enum
 #define DEFAULT_PROP_SERVER 		NULL
 #define DEFAULT_PROP_CLIENT_NAME	NULL
 #define DEFAULT_PROP_TRANSPORT	GST_JACK_TRANSPORT_AUTONOMOUS
-
+#define DEFAULT_PROP_PORT_PATTERN     	NULL
 enum
 {
   PROP_0,
@@ -688,11 +694,11 @@ enum
   PROP_SERVER,
   PROP_CLIENT,
   PROP_CLIENT_NAME,
+  PROP_PORT_PATTERN,
   PROP_TRANSPORT,
   PROP_LAST
 };
 
-
 /* the capabilities of the inputs and outputs.
  *
  * describe the real formats here.
@@ -771,6 +777,18 @@ gst_jack_audio_src_class_init (GstJackAudioSrcClass * klass)
           GST_TYPE_JACK_CLIENT,
           GST_PARAM_MUTABLE_READY | G_PARAM_READWRITE |
           G_PARAM_STATIC_STRINGS));
+   /**
+    * GstJackAudioSrc:port-pattern
+    *
+    * autoconnect to ports matching pattern, when NULL connect to physical ports
+    *
+    * Since: 1.6
+    */
+  g_object_class_install_property (gobject_class, PROP_PORT_PATTERN,
+      g_param_spec_string ("port-pattern", "port pattern",
+          "A pattern to select which ports to connect to (NULL = first physical ports)",
+          DEFAULT_PROP_PORT_PATTERN,
+          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   /**
    * GstJackAudioSink:transport:
@@ -783,8 +801,7 @@ gst_jack_audio_src_class_init (GstJackAudioSrcClass * klass)
           GST_TYPE_JACK_TRANSPORT, DEFAULT_PROP_TRANSPORT,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&src_factory));
+  gst_element_class_add_static_pad_template (gstelement_class, &src_factory);
 
   gst_element_class_set_static_metadata (gstelement_class,
       "Audio Source (Jack)", "Source/Audio",
@@ -828,6 +845,11 @@ gst_jack_audio_src_dispose (GObject * object)
     src->client_name = NULL;
   }
 
+  if (src->port_pattern != NULL) {
+    g_free (src->port_pattern);
+    src->port_pattern = NULL;
+  }
+
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -842,6 +864,10 @@ gst_jack_audio_src_set_property (GObject * object, guint prop_id,
       g_free (src->client_name);
       src->client_name = g_value_dup_string (value);
       break;
+    case PROP_PORT_PATTERN:
+      g_free (src->port_pattern);
+      src->port_pattern = g_value_dup_string (value);
+      break;
     case PROP_CONNECT:
       src->connect = g_value_get_enum (value);
       break;
@@ -874,6 +900,9 @@ gst_jack_audio_src_get_property (GObject * object, guint prop_id,
     case PROP_CLIENT_NAME:
       g_value_set_string (value, src->client_name);
       break;
+    case PROP_PORT_PATTERN:
+      g_value_set_string (value, src->port_pattern);
+      break;
     case PROP_CONNECT:
       g_value_set_enum (value, src->connect);
       break;
