@@ -23,13 +23,13 @@
 
 /**
  * SECTION:element-pulsesink
+ * @title: pulsesink
  * @see_also: pulsesrc
  *
  * This element outputs audio to a
- * <ulink href="http://www.pulseaudio.org">PulseAudio sound server</ulink>.
+ * [PulseAudio sound server](http://www.pulseaudio.org).
  *
- * <refsect2>
- * <title>Example pipelines</title>
+ * ## Example pipelines
  * |[
  * gst-launch-1.0 -v filesrc location=sine.ogg ! oggdemux ! vorbisdec ! audioconvert ! audioresample ! pulsesink
  * ]| Play an Ogg/Vorbis file.
@@ -40,7 +40,7 @@
  * gst-launch-1.0 -v audiotestsrc ! pulsesink stream-properties="props,media.title=test"
  * ]| Play a sine wave and set a stream property. The property can be checked
  * with "pactl list".
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -154,7 +154,7 @@ static guint mainloop_ref_ct = 0;
 static GMutex pa_shared_resource_mutex;
 
 /* We keep a custom ringbuffer that is backed up by data allocated by
- * pulseaudio. We must also overide the commit function to write into
+ * pulseaudio. We must also override the commit function to write into
  * pulseaudio memory instead. */
 struct _GstPulseRingBuffer
 {
@@ -545,7 +545,7 @@ gst_pulseringbuffer_open_device (GstAudioRingBuffer * buf)
         gst_pulsering_context_subscribe_cb, pctx);
 
     /* try to connect to the server and wait for completion, we don't want to
-     * autospawn a deamon */
+     * autospawn a daemon */
     GST_LOG_OBJECT (psink, "connect to server %s",
         GST_STR_NULL (psink->server));
     if (pa_context_connect (pctx->context, psink->server,
@@ -685,7 +685,7 @@ gst_pulsering_stream_request_cb (pa_stream * s, size_t length, void *userdata)
 
   if (pbuf->in_commit && (length >= rbuf->spec.segsize)) {
     /* only signal when we are waiting in the commit thread
-     * and got request for atleast a segment */
+     * and got request for at least a segment */
     pa_threaded_mainloop_signal (mainloop, 0);
   }
 }
@@ -1815,11 +1815,6 @@ static gboolean gst_pulsesink_query (GstBaseSink * sink, GstQuery * query);
 static GstStateChangeReturn gst_pulsesink_change_state (GstElement * element,
     GstStateChange transition);
 
-static GstStaticPadTemplate pad_template = GST_STATIC_PAD_TEMPLATE ("sink",
-    GST_PAD_SINK,
-    GST_PAD_ALWAYS,
-    GST_STATIC_CAPS (PULSE_SINK_TEMPLATE_CAPS));
-
 #define gst_pulsesink_parent_class parent_class
 G_DEFINE_TYPE_WITH_CODE (GstPulseSink, gst_pulsesink, GST_TYPE_AUDIO_BASE_SINK,
     gst_pulsesink_init_contexts ();
@@ -1891,6 +1886,7 @@ gst_pulsesink_class_init (GstPulseSinkClass * klass)
   GstBaseSinkClass *bc;
   GstAudioBaseSinkClass *gstaudiosink_class = GST_AUDIO_BASE_SINK_CLASS (klass);
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (klass);
+  GstCaps *caps;
   gchar *clientname;
 
   gobject_class->finalize = gst_pulsesink_finalize;
@@ -1963,7 +1959,7 @@ gst_pulsesink_class_init (GstPulseSinkClass * klass)
    * GstPulseSink:stream-properties:
    *
    * List of pulseaudio stream properties. A list of defined properties can be
-   * found in the <ulink url="http://0pointer.de/lennart/projects/pulseaudio/doxygen/proplist_8h.html">pulseaudio api docs</ulink>.
+   * found in the [pulseaudio api docs](http://0pointer.de/lennart/projects/pulseaudio/doxygen/proplist_8h.html).
    *
    * Below is an example for registering as a music application to pulseaudio.
    * |[
@@ -1983,7 +1979,12 @@ gst_pulsesink_class_init (GstPulseSinkClass * klass)
   gst_element_class_set_static_metadata (gstelement_class,
       "PulseAudio Audio Sink",
       "Sink/Audio", "Plays audio to a PulseAudio server", "Lennart Poettering");
-  gst_element_class_add_static_pad_template (gstelement_class, &pad_template);
+
+  caps =
+      gst_pulse_fix_pcm_caps (gst_caps_from_string (PULSE_SINK_TEMPLATE_CAPS));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_pad_template_new ("sink", GST_PAD_SINK, GST_PAD_ALWAYS, caps));
+  gst_caps_unref (caps);
 }
 
 static void
@@ -2430,7 +2431,7 @@ gst_pulsesink_set_volume (GstPulseSink * psink, gdouble volume)
   if (pbuf->is_pcm)
     gst_pulse_cvolume_from_linear (&v, pbuf->channels, volume);
   else
-    /* FIXME: this will eventually be superceded by checks to see if the volume
+    /* FIXME: this will eventually be superseded by checks to see if the volume
      * is readable/writable */
     goto unlock;
 
@@ -3002,7 +3003,7 @@ gst_pulsesink_change_props (GstPulseSink * psink, GstTagList * l)
   static const gchar *const map[] = {
     GST_TAG_TITLE, PA_PROP_MEDIA_TITLE,
 
-    /* might get overriden in the next iteration by GST_TAG_ARTIST */
+    /* might get overridden in the next iteration by GST_TAG_ARTIST */
     GST_TAG_PERFORMER, PA_PROP_MEDIA_ARTIST,
 
     GST_TAG_ARTIST, PA_PROP_MEDIA_ARTIST,
